@@ -1,4 +1,6 @@
 import pytest
+from executing import is_pytest_compatible
+
 from inline_snapshot import snapshot
 from inline_snapshot.testing import Example
 
@@ -115,7 +117,16 @@ def test_a():
 
     result.assert_outcomes(passed=1)
 
-    assert result.report == snapshot("")
+    assert result.report == (
+        snapshot(
+            """\
+Info: one snapshot changed its representation (--inline-snapshot=update)
+You can also use --inline-snapshot=review to approve the changes interactively
+"""
+        )
+        if is_pytest_compatible()
+        else snapshot("")
+    )
 
     result = project.run("--inline-snapshot=update")
 
@@ -202,12 +213,23 @@ def test_a():
 
     result.assert_outcomes(failed=1, errors=1)
 
-    assert result.report == snapshot(
-        """\
+    assert result.report == (
+        snapshot(
+            """\
+Error: one snapshot has incorrect values (--inline-snapshot=fix)
+Info: one snapshot can be trimmed (--inline-snapshot=trim)
+Info: one snapshot changed its representation (--inline-snapshot=update)
+You can also use --inline-snapshot=review to approve the changes interactively
+"""
+        )
+        if is_pytest_compatible()
+        else snapshot(
+            """\
 Error: one snapshot has incorrect values (--inline-snapshot=fix)
 Info: one snapshot can be trimmed (--inline-snapshot=trim)
 You can also use --inline-snapshot=review to approve the changes interactively
 """
+        )
     )
 
     result = project.run("--inline-snapshot=trim,fix")
@@ -676,10 +698,140 @@ UsageError:
 inline-snapshot uses `copy.deepcopy` to copy objects,
 but the copied object is not equal to the original one:
 
-original: Thing()
-copied:   Thing()
+value = Thing()
+copied_value = copy.deepcopy(value)
+assert value == copied_value
 
 Please fix the way your object is copied or your __eq__ implementation.
 """
         ),
     )
+
+
+def test_equal_check_2():
+
+    Example(
+        {
+            "test_a.py": """
+from inline_snapshot import snapshot
+
+class A:
+    def __eq__(self,other):
+        if isinstance(other,A):
+            return False
+        return NotImplemented
+
+    def __repr__(self):
+        return "A()"
+
+def test_a():
+    assert A() == snapshot(A())
+    """,
+        }
+    ).run_inline(
+        ["--inline-snapshot=create"],
+        changed_files=snapshot({}),
+        raises=snapshot(
+            """\
+UsageError:
+inline-snapshot uses `copy.deepcopy` to copy objects,
+but the copied object is not equal to the original one:
+
+value = A()
+copied_value = copy.deepcopy(value)
+assert value == copied_value
+
+Please fix the way your object is copied or your __eq__ implementation.
+"""
+        ),
+    )
+
+
+def test_unknown_flag():
+
+    Example(
+        """\
+def test_a():
+    assert 1==1
+"""
+    ).run_pytest(
+        ["--inline-snapshot=creaigflen"],
+        report=snapshot(""),
+        returncode=snapshot(4),
+        stderr=snapshot("ERROR: --inline-snapshot=creaigflen is a unknown flag\n"),
+    )
+
+
+@pytest.mark.parametrize("storage_dir", ["tests/snapshots", None])
+def test_storage_dir_config(project, tmp_path, storage_dir):
+    # Relative path case: `tests/snapshots` (parametrized).
+    # Absolute path case: `tmp_path / "snapshots"` (parametrized as `None`).
+    if not storage_dir:
+        storage_dir = tmp_path / "snapshots"
+
+    project.pyproject(
+        f"""
+[tool.inline-snapshot]
+storage-dir = {str(storage_dir)!r}
+"""
+    )
+
+    project.setup(
+        """
+from inline_snapshot import outsource, snapshot
+
+def test_outsource():
+    assert outsource("hello", suffix=".html") == snapshot()
+"""
+    )
+
+    result = project.run("--inline-snapshot=create")
+    assert result.ret == 0
+    assert project.source == snapshot(
+        """\
+from inline_snapshot import outsource, snapshot
+
+from inline_snapshot import external
+
+def test_outsource():
+    assert outsource("hello", suffix=".html") == snapshot(external("2cf24dba5fb0*.html"))
+"""
+    )
+
+    project.run("--inline-snapshot=fix")
+    assert result.ret == 0
+
+    assert project.storage(storage_dir) == snapshot(
+        ["2cf24dba5fb0a30e26e83b2ac5b9e29e1b161e5c1fa7425e73043362938b9824.html"]
+    )
+
+
+def test_find_pyproject_in_parent_directories(tmp_path):
+
+    Example(
+        {
+            "pyproject.toml": """\
+[tool.inline-snapshot]
+hash-length=2
+""",
+            "project/pytest.ini": "",
+            "project/test_something.py": """\
+from inline_snapshot import outsource,snapshot,external
+
+def test_something():
+    assert outsource("test") == snapshot()
+""",
+        }
+    ).run_pytest(
+        ["--rootdir", "./project", "--inline-snapshot=create"],
+        changed_files=snapshot(
+            {
+                "project/test_something.py": """\
+from inline_snapshot import outsource,snapshot,external
+
+def test_something():
+    assert outsource("test") == snapshot(external("9f*.txt"))
+"""
+            }
+        ),
+    )
